@@ -11,27 +11,22 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
-# Copyright 2018 SerialLab Corp.  All rights reserved.
+# Copyright 2024 SerialLab Corp.  All rights reserved.
 from rest_framework.routers import DefaultRouter
 from serialbox.api import viewsets
+
 router = DefaultRouter()
 
 router.register(
-    r'response-rules',
-    viewsets.ResponseRuleViewSet,
-    basename='response-rules'
+    r"response-rules", viewsets.ResponseRuleViewSet, basename="response-rules"
 )
 
 router.register(
-    r'response-rules/pool/(?P<pool_id>\d{1,20})',
+    r"response-rules/pool/(?P<pool_id>\d{1,20})",
     viewsets.ResponseRuleViewSet,
-    basename='filtered-response-rules'
+    basename="filtered-response-rules",
 )
 
-router.register(
-    r'v2/pools',
-    viewsets.PoolViewSet,
-    basename='pools'
-)
+router.register(r"v2/pools", viewsets.PoolViewSet, basename="pools")
 
 urlpatterns = router.urls
