@@ -11,7 +11,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
-# Copyright 2018 SerialLab Corp.  All rights reserved.
+# Copyright 2024 SerialLab Corp.  All rights reserved.
 
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -26,28 +26,27 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
-# Copyright 2018 SerialLab Corp.  All rights reserved.
+# Copyright 2024 SerialLab Corp.  All rights reserved.
 from django.utils.translation import gettext as _
 from django.core.management.base import BaseCommand
 from serialbox import models
 
+
 class Command(BaseCommand):
-    help = _(
-        'Loads some example rules into the database.'
-    )
+    help = _("Loads some example rules into the database.")
 
     def handle(self, *args, **options):
         sp1 = models.Pool.objects.create(
-            readable_name=_('Logositol 100mg Cartons'),
-            machine_name='00377700000136',
+            readable_name=_("Logositol 100mg Cartons"),
+            machine_name="00377700000136",
             active=True,
-            request_threshold=1000
+            request_threshold=1000,
         )
         models.SequentialRegion.objects.create(
-            readable_name=_('Logositol 100mg Cartons'),
-            machine_name='00377700000136',
+            readable_name=_("Logositol 100mg Cartons"),
+            machine_name="00377700000136",
             order=1,
             start=1,
             end=9999999999,
-            pool=sp1
-        )
\ No newline at end of file
+            pool=sp1,
+        )
